//*************************************************************************
//* -----------
//* CDCAnalysis
//* -----------
//* (Description)
//* 	Clasess to analyze CDC data.
//* (Update Record)
//*	2000/05/16  K.Fujii	Original version.
//*************************************************************************

#include "JSFSteer.h"
#include "CDCAnalysis.h"
#include <iostream.h>

ClassImp(CDCAnalysis)

const Int_t CDCAnalysis::kZoneX   = 4;
const Int_t CDCAnalysis::kZoneY   = 3;
const Int_t CDCAnalysis::kNh = kZoneX*kZoneY;

//___________________________________________________________________________
CDCAnalysis::CDCAnalysis(const Char_t *name, const Char_t *title)
	: JSFModule(name, title), fMode(0), fNwires(5)
{
   hdefr = new THdef2[kNh];
   hdefp = new THdef2[kNh];
   Char_t st[256], std[256];
   Int_t i;
   for (i = 0; i < kNh; i++) {
      sprintf(st,"CDCAnalysis.hRes%2.2d",i);
      sprintf(std,"x-dx for ch %2.2d, 50,0.,5.,200,-0.2,0.2",i);
      sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g,%d,%g,%g",
      			 hdefr[i].title,
			&hdefr[i].nxbin, &hdefr[i].xmin, &hdefr[i].xmax,
			&hdefr[i].nybin, &hdefr[i].ymin, &hdefr[i].ymax);
      sprintf(st,"CDCAnalysis.hPh%2.2d",i);
      sprintf(std,"x-ph for ch %2.2d, 50,0.,5.,200,0.,10000.",i);
      sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g,%d,%g,%g",
      			 hdefp[i].title,
			&hdefp[i].nxbin, &hdefp[i].xmin, &hdefp[i].xmax,
			&hdefp[i].nybin, &hdefp[i].ymin, &hdefp[i].ymax);
   }
   hRes = new TH2F* [kNh];
   hPh  = new TH2F* [kNh];
}

//___________________________________________________________________________
CDCAnalysis::~CDCAnalysis()
{
   delete hdefr;
   delete hdefp;
   Int_t i;
   for (i = 0; i < kNh; i++) {
   	delete hRes[i];
   	delete hPh[i];
   }
   delete hRes;
   delete hPh;
}

//___________________________________________________________________________
Bool_t CDCAnalysis::Initialize()
{
   TDirectory *last = gDirectory;
   gFile->cd("/");
   Int_t i;
   for (i = 0; i < kNh; i++) {
      hRes[i] = new TH2F(hdefr[i].title,hdefr[i].title,
      			hdefr[i].nxbin,hdefr[i].xmin,hdefr[i].xmax,
      			hdefr[i].nybin,hdefr[i].ymin,hdefr[i].ymax);
      cout << i << " "      << hdefr[i].title 
      		<< " nx "   << hdefr[i].nxbin
      		<< " xmin " << hdefr[i].xmin
      		<< " xmax " << hdefr[i].xmax
      		<< " ny "   << hdefr[i].nybin
      		<< " ymin " << hdefr[i].ymin
      		<< " ymax " << hdefr[i].ymax
      		<< endl;
   }
   for (i = 0; i < kNh; i++) {
      hPh[i] = new TH2F(hdefp[i].title,hdefp[i].title,
      			hdefp[i].nxbin,hdefp[i].xmin,hdefp[i].xmax,
      			hdefp[i].nybin,hdefp[i].ymin,hdefp[i].ymax);
      cout << i << " "      << hdefp[i].title 
      		<< " nx "   << hdefp[i].nxbin
      		<< " xmin " << hdefp[i].xmin
      		<< " xmax " << hdefp[i].xmax
      		<< " ny "   << hdefp[i].nybin
      		<< " ymin " << hdefp[i].ymin
      		<< " ymax " << hdefp[i].ymax
      		<< endl;
   }
   hc1 = new TCanvas("hc1","Canvas 1",20, 20, 200*kZoneX, 200*kZoneY);
   hc1->Divide(kZoneX,kZoneY);
   last->cd();
   return kTRUE;
}


//___________________________________________________________________________
Bool_t CDCAnalysis::Process(Int_t ev)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");

   CDCTrackMaker *tm = (CDCTrackMaker*)gJSF->FindModule("CDCTrackMaker");
   CDCTrackBuf   *tb = (CDCTrackBuf *)tm->EventBuf();
   CDCTrack	 *tp = (CDCTrack *)tb->GetTracks();
   TIter nexttk(tp);
   while ((tp = (CDCTrack *)nexttk())) {
      if (tp->GetEntries() < fNwires) continue;	// require fNwires wires
      CDCTrackHit *hitp;
      CDCHit *htp;
      CDCTrack trk(*tp);
      TIter next(&trk);
      while ((hitp = (CDCTrackHit *)next())) {
         htp = hitp->GetCDCHit();
         Int_t layer = htp->GetLayerNo();
         Int_t cell  = htp->GetCellNo();
         Int_t wire  = htp->GetWireNo();
         Int_t a = 5*layer + wire;		// works only for baby 
         if (cell == 1) a = 10 + wire;		// works only for baby
         if (fMode == 0) { 
	 	hitp->Lock();			// lock this hit and
         	trk.Update();			// exclude it from fit
         }
         Double_t x   = trk.Xat(htp->Ywire()) - htp->Xwire();
         Double_t dx  = hitp->GetResidual();
         Double_t ph = hitp->GetCDCHit()->GetCluster()->GetSum();
         if ( a >= 0 && a < CDCAnalysis::kNh ) {
      	    hRes[a]->Fill(x,dx,1.0);
      	    hPh[a]->Fill(x,ph,1.0);
         }
         if (fMode == 0) hitp->Unlock();	// unlock this hit
      }
   }
   if (!(gROOT->IsBatch())) Draw();
   last->cd();
   return kTRUE;
}

//___________________________________________________________________________
void CDCAnalysis::Draw(Option_t *opt)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");
   Int_t i;
   for (i = 0; i < CDCAnalysis::kNh; i++) {
      hc1->cd(i+1);
      hRes[i]->Draw();
      hc1->Update();
   }
   last->cd();
}


