#ifndef __CDCANALYSIS__
#define __CDCANALYSIS__

//*************************************************************************
//* -----------
//* CDCAnalysis
//* -----------
//* (Description)
//* 	Clasess to analyze CDC data.
//* (Update Record)
//*	2000/05/16  K.Fujii	Original version.
//*************************************************************************

#include "TObject.h"
#include "TH2.h"
#include "TCanvas.h"

#include "CDCTrackMaker.h"

class CDCAnalysis : public JSFModule {
public:
   CDCAnalysis(const Char_t *name="CDCAnalysis",
		  const Char_t *title="CDC Analysis");
   virtual ~CDCAnalysis();

   inline Int_t GetMode  ()  const { return fMode;   }
   inline Int_t GetNwires()  const { return fNwires; }
   inline void  SetMode  (Int_t n) { fMode   = n;    }
   inline void  SetNwires(Int_t n) { fNwires = n;    }

   Bool_t Initialize();
   Bool_t Process(Int_t ev);
   
   void Draw(Option_t *option="");

private:
   struct THdef1 {
      Char_t   title[256];
      Int_t    nbin;
      Float_t  xmin;
      Float_t  xmax;
   };
   struct THdef2 {
      Char_t   title[256];
      Int_t    nxbin;
      Float_t  xmin;
      Float_t  xmax;
      Int_t    nybin;
      Float_t  ymin;
      Float_t  ymax;
   };
   Int_t    fMode;		//! (0,1) = (excl,incl) wire in question
   Int_t    fNwires;		//! # wires required
   TH2F    **hRes;		//! residual plots
   TH2F    **hPh;		//! ph sum plots
   TCanvas  *hc1;		//! Canvas to draw histograms
   THdef2   *hdefr;		//! histogram parameters for hRes
   THdef2   *hdefp;		//! histogram parameters for hPh
   static const Int_t kNh;	//! # hists
   static const Int_t kZoneX;	//! # X divisions
   static const Int_t kZoneY;	//! # Y divisions

   ClassDef(CDCAnalysis, 1) // CDC Analysis class
};

#endif


